@@ -23,9 +23,11 @@ template <typename T, int R, int C>
 inline Eigen::Matrix<double, R, C> value_of_rec(
     const Eigen::Matrix<T, R, C>& M) {
   Eigen::Matrix<double, R, C> Md(M.rows(), M.cols());
-  for (int j = 0; j < M.cols(); j++)
-    for (int i = 0; i < M.rows(); i++)
+  for (int j = 0; j < M.cols(); j++) {
+    for (int i = 0; i < M.rows(); i++) {
       Md(i, j) = value_of_rec(M(i, j));
+    }
+  }
   return Md;
 }
 
