@@ -1,11 +1,12 @@
 #ifndef STAN_MATH_PRIM_SCAL_FUN_LB_FREE_HPP
 #define STAN_MATH_PRIM_SCAL_FUN_LB_FREE_HPP
 
+#include <stan/math/prim/meta.hpp>
 #include <stan/math/prim/scal/fun/identity_free.hpp>
+#include <stan/math/prim/scal/fun/constants.hpp>
 #include <stan/math/prim/scal/err/check_greater_or_equal.hpp>
 #include <boost/math/tools/promotion.hpp>
 #include <cmath>
-#include <limits>
 
 namespace stan {
 namespace math {
@@ -26,11 +27,11 @@ namespace math {
  * @throw std::domain_error if y is lower than the lower bound
  */
 template <typename T, typename L>
-inline typename boost::math::tools::promote_args<T, L>::type lb_free(
-    const T& y, const L& lb) {
+inline return_type_t<T, L> lb_free(const T& y, const L& lb) {
   using std::log;
-  if (lb == -std::numeric_limits<double>::infinity())
+  if (lb == NEGATIVE_INFTY) {
     return identity_free(y);
+  }
   check_greater_or_equal("lb_free", "Lower bounded variable", y, lb);
   return log(y - lb);
 }
