@@ -1,6 +1,7 @@
 #ifndef STAN_MATH_PRIM_SCAL_FUN_PROMOTE_SCALAR_TYPE_HPP
 #define STAN_MATH_PRIM_SCAL_FUN_PROMOTE_SCALAR_TYPE_HPP
 
+#include <stan/math/prim/meta.hpp>
 namespace stan {
 namespace math {
 
@@ -16,9 +17,12 @@ struct promote_scalar_type {
   /**
    * The promoted type.
    */
-  typedef T type;
+  using type = T;
 };
 
+template <typename T, typename S>
+using promote_scalar_t = typename promote_scalar_type<T, S>::type;
+
 }  // namespace math
 }  // namespace stan
 #endif
