@@ -6,11 +6,10 @@
 
 namespace stan {
 
-  template <typename T>
-  inline T get(const T& x, size_t n) {
-    return x;
-  }
-
+template <typename T>
+inline T get(const T& x, size_t n) {
+  return x;
 }
-#endif
 
+}  // namespace stan
+#endif
