@@ -13,8 +13,9 @@ inline var& var::operator-=(const var& b) {
 }
 
 inline var& var::operator-=(double b) {
-  if (b == 0.0)
+  if (b == 0.0) {
     return *this;
+  }
   vi_ = new internal::subtract_vd_vari(vi_, b);
   return *this;
 }
