@@ -1,13 +1,11 @@
 #ifndef STAN_MATH_REV_MAT_FUN_COLUMNS_DOT_SELF_HPP
 #define STAN_MATH_REV_MAT_FUN_COLUMNS_DOT_SELF_HPP
 
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/prim/mat/fun/Eigen.hpp>
-#include <stan/math/prim/mat/fun/typedefs.hpp>
-#include <stan/math/prim/mat/err/check_vector.hpp>
 #include <stan/math/rev/core.hpp>
 #include <stan/math/rev/mat/fun/typedefs.hpp>
 #include <stan/math/rev/mat/fun/dot_self.hpp>
-#include <vector>
 
 namespace stan {
 namespace math {
