@@ -1,9 +1,9 @@
 #ifndef STAN_MATH_REV_SCAL_FUN_ACOS_HPP
 #define STAN_MATH_REV_SCAL_FUN_ACOS_HPP
 
+#include <stan/math/rev/meta.hpp>
 #include <stan/math/rev/core.hpp>
 #include <cmath>
-#include <valarray>
 
 namespace stan {
 namespace math {
